==> scpdb-0.55.3.tgz: package/app/components/interwiki/strings.ts <==

type StringDictionary = {[key: string]: {[key: string]: string}};

const strings: StringDictionary = {
    ru: {
        in_other_languages: 'На других языках'
    },
    en: {
        in_other_languages: 'Languages'
    },
    pl: {
        in_other_languages: 'W innych językach'
    },
    de: {
        in_other_languages: 'In anderen Sprachen'
    },
    cn: {
        in_other_languages: '其他语言'
    },
    es: {
        in_other_languages: 'En otros idiomas'
    },
    it: {
        in_other_languages: 'In altre lingue'
    },
    th: {
        in_other_languages: 'ภาษาอื่น'
    },
    ko: {
        in_other_languages: '다른 언어'
    },
    jp: {
        in_other_languages: '他言語版'
    },
    fr: {
        in_other_languages: 'Dans d’autres langues'
    },
    ua: {
        in_other_languages: 'Іншими мовами'
    }
};

export const languagesByWikis: StringDictionary = {
    'scp-ru': {
        title: 'Русский',
        name: 'Russian'
    },
    'scp-wiki': {
        title: 'English',
        name: 'English'
    },
    'scp-wiki-de': {
        title: 'Deutsch',
        name: 'German'
    },
    'scp-pl': {
        title: 'Polski',
        name: 'Polish'
    },
    'fondationscp': {
        title: 'Français',
        name: 'French'
    },
    'lafundacionscp': {
        title: 'Español',
        name: 'Spanish'
    },
    'fondazionescp': {
        title: 'Italiano',
        name: 'Italian'
    },
    'scp-wiki-cn': {
        title: '中文',
        name: 'Chinese'
    },
    'scp-kr': {
        title: '한국어',
        name: 'Korean'
    },
    'scp-jp': {
        title: '日本語',
        name: 'Janapese'
    },
    'scp-th': {
        title: 'ภาษาไทย',
        name: 'Thai'
    },
    'scp-ukrainian': {
        title: 'Український',
        name: 'Ukrainian'
    }
};

export function getKeyset(lang: string) {
    const keyset = strings[lang] || {};
    return (key: string) => keyset[key] || key;
}

==> scpdb-1.6.1.tgz: package/app/components/interwiki/strings.ts <==

type StringDictionary = {[key: string]: {[key: string]: string}};

const strings: StringDictionary = {
    ru: {
        in_other_languages: 'На других языках'
    },
    en: {
        in_other_languages: 'Languages'
    },
    pl: {
        in_other_languages: 'W innych językach'
    },
    de: {
        in_other_languages: 'In anderen Sprachen'
    },
    cn: {
        in_other_languages: '其他语言'
    },
    es: {
        in_other_languages: 'En otros idiomas'
    },
    it: {
        in_other_languages: 'In altre lingue'
    },
    th: {
        in_other_languages: 'ภาษาอื่น'
    },
    ko: {
        in_other_languages: '다른 언어'
    },
    jp: {
        in_other_languages: '他言語版'
    },
    fr: {
        in_other_languages: 'Dans d’autres langues'
    },
    ua: {
        in_other_languages: 'Іншими мовами'
    }
};

export const languagesByWikis: StringDictionary = {
    'scp-ru': {
        title: 'Русский',
        name: 'Russian'
    },
    'scp-wiki': {
        title: 'English',
        name: 'English'
    },
    'scp-wiki-de': {
        title: 'Deutsch',
        name: 'German'
    },
    'scp-pl': {
        title: 'Polski',
        name: 'Polish'
    },
    'fondationscp': {
        title: 'Français',
        name: 'French'
    },
    'lafundacionscp': {
        title: 'Español',
        name: 'Spanish'
    },
    'fondazionescp': {
        title: 'Italiano',
        name: 'Italian'
    },
    'scp-wiki-cn': {
        title: '中文',
        name: 'Chinese'
    },
    'scp-kr': {
        title: '한국어',
        name: 'Korean'
    },
    'scp-jp': {
        title: '日本語',
        name: 'Janapese'
    },
    'scp-th': {
        title: 'ภาษาไทย',
        name: 'Thai'
    },
    'scp-ukrainian': {
        title: 'Українська',
        name: 'Ukrainian'
    }
};

export function getKeyset(lang: string) {
    const keyset = strings[lang] || {};
    return (key: string) => keyset[key] || key;
}
